==> moodle-1.5-pgsql.tgz: moodle/lang/tl/assignment.php <==
<?PHP // $Id$ 
      // assignment.php - created with Moodle 1.5 ALPHA (2005051500)


$string['allowresubmit'] = 'Pahintulutang mapasa mul';
$string['assignmentdetails'] = 'Detalye ng takdang-aralin';
$string['assignmentmail'] = 'Nagpost si $a->teacher ng puna sa ipinasa mong 
takdang-aralin para sa  \'$a->assignment\'

Makikita mo itong nakakabit sa ipinasa mong takdang-aralin:

    $a->url';
$string['assignmentmailhtml'] = 'Nagpost si $a->teacher ng ilang puna sa ipinasa mong 
takdang-aralin para sa \'<i>$a->assignment</i>\'<br /><br />
Makikita mo itong nakakabit sa <a href=\"$a->url\">ipinasa mong takdang-aralin</a>.';
$string['assignmentname'] = 'Pangalan ng takdang-aralin';
$string['assignmenttype'] = 'Uri ng takdang-aralin';
$string['availabledate'] = 'Magagamit mula ';
$string['comment'] = 'Opinyon';
$string['commentinline'] = 'Opinyong inline';
$string['configmaxbytes'] = 'Default na maksimum na laki ng takdang-aralin para sa lahat ng takdang-aralin na nasa site (alinsunod sa limitasyon sa kurso at iba pang lokal na kaayusan)';
$string['description'] = 'Deskripsiyon';
$string['duedate'] = 'Huling araw ng pasahan';
$string['duedateno'] = 'Walang huling araw ng pasahan';
$string['early'] = '$a maaga';
$string['editmysubmission'] = 'Iedit ang ipinasa ko';
$string['emailteachermail'] = 'Binago ni $a->username ang ipinasa niyang takdang -aralin para sa \'$a->assignment\'

Makukuha ito rito:

$a->url';
$string['emailteachermailhtml'] = 'Binago ni $a->username ang kanyang ipinasang takdang-aralin para sa <i>\'$a->assignment\'</i><br /><br />
Makukuha ito sa <a href=\"$a->url\">web site</a>.';
$string['emailteachers'] = 'Hudyat na email para sa mga guro';
$string['emptysubmission'] = 'Wala ka pang ipinapasang anuman';
$string['existingfiledeleted'] = 'Ang kasalukuyang file ay binura na: $a';
$string['failedupdatefeedback'] = 'Nabigong baguhin ang puna sa ipinasa ni user $a';
$string['feedback'] = 'Puna';
$string['feedbackfromteacher'] = 'Puna mula sa $a';
$string['feedbackupdated'] = 'Nabago na ang puna sa mga ipinasa ng $a tao';
$string['helpoffline'] = '<p>Kapakipakinabang ito kapag ang takdang-aralin ay ginagawa sa labas ng Moodle.  Maaari itong isang bagay sa iba pang lugar sa web o harapan.</p><p>Maaaring makakita ng deskripsyon ng takdang-aralin ang mga mag-aaral, nguni hindi puwedeng mag-aplowd ng file o anupaman.  Gumagana ng normal ang pagmamarka, at tatanggap ng patalastas hinggil sa marka nila ang mga mag-aaral</p>';
$string['helponline'] = '<p>Ang uri ng takdang-aralin na ito ay humihiling sa mga user na mag-edit ng teksto, gamit ang mga normal na editing tool.  Maaari itong markahan ng mga guro nang online, at puwede ring magdagdag ng inline na puno o pagbabago.</p><p>(Kung pamilyar ka sa mga lumang bersiyon ng Moodle, pareho ang silbi ng uri ng Takdang-aralin na ito sa lumang diyornal na modyul.)</p>';
$string['helpuploadsingle'] = '<p>Ang uri ng takdang-aralin na ito ay pinapahintulutan ang bawat kalahok na mag-aplowd ng isang file, anuman ang uri.</p><p>Maaari itong maging Word processor na dokumento, o isang larawan, isang nakazip na web site, o anumang bagay na hilingin mong ipasa nila.</p>';
$string['late'] = '$a huli';
$string['maximumgrade'] = 'Pinakamataas na marka';
$string['maximumsize'] = 'Pinakamataas na laki';
$string['modulename'] = 'Takdang-aralin';
$string['modulenameplural'] = 'Mga takdang-aralin';
$string['newsubmissions'] = 'Ipinasang takdang-aralin';
$string['noassignments'] = 'Wala pang takdang-aralin';
$string['noattempts'] = 'Wala pang kumukuha ng takdang-aralin na ito';
$string['notgradedyet'] = 'Hindi pa namamarkahan';
$string['notsubmittedyet'] = 'Hindi pa naipapasa';
$string['overwritewarning'] = 'Babala: kung mag-aaplowd kang mul, MAPAPALITAN nito ang kasalukuyan mong ipinasa';
$string['preventlate'] = 'Pigilan ang pagpapasa nang hul';
$string['saveallfeedback'] = 'Isave ang lahat ng aking puna';
$string['submission'] = 'Ipinasa';
$string['submissionfeedback'] = 'Puna sa ipinasa';
$string['submissions'] = 'Mga ipinasa';
$string['submissionsaved'] = 'Naisave na ang mga pagbabago mo';
$string['submitassignment'] = 'Ipasa ang iyong takdang-aralin sa pamamagitan ng form na ito';
$string['submitted'] = 'Naipasa na';
$string['typeoffline'] = 'Offline na aktibidad';
$string['typeonline'] = 'Online na teksto';
$string['typeuploadsingle'] = 'Mag-aplowd ng isang file lamang';
$string['uploadbadname'] = 'May mga kakaibang titik ang filename na ito at hindi puwedeng maiaplowd';
$string['uploadedfiles'] = 'mga naiaplowd nang file';
$string['uploaderror'] = 'May error na naganap habang isinisave ang file sa server';
$string['uploadfailnoupdate'] = 'OK ang pagkakaaplowd ng file pero hindi mabago ang ipinasa mo!';
$string['uploadfiletoobig'] = 'Paumanhin, pero masyadong malaki ang file na iyan (ang limitasyon ay $a bytes)';
$string['uploadnofilefound'] = 'Wala pong makitang file - sigurado ba kayong may pinili kayong file para iaplowd?';
$string['uploadnotregistered'] = 'OK ang pagkakaaplowd ng \'$a\' pero hindi rumehistro ang ipinasa!';
$string['uploadsuccess'] = 'Matagumpay na naiaplowd ang \'$a\' ';
$string['viewfeedback'] = 'Tingnan ang mga marka at puna ng takdang-aralin';
$string['viewsubmissions'] = 'Tingnan ang $a naipasa nang takdang-aralin';
$string['yoursubmission'] = 'Ang iyong ipinasa';

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/tl/assignment.php <==
<?PHP // $Id$ 
      // assignment.php - created with Moodle 1.6 development (2005060201)


$string['allowresubmit'] = 'Pahintulutang mapasa mul';
$string['assignmentdetails'] = 'Detalye ng takdang-aralin';
$string['assignmentmail'] = 'Nagpost si $a->teacher ng puna sa ipinasa mong 
takdang-aralin para sa  \'$a->assignment\'

Makikita mo itong nakakabit sa ipinasa mong takdang-aralin:

    $a->url';
$string['assignmentmailhtml'] = 'Nagpost si $a->teacher ng ilang puna sa ipinasa mong 
takdang-aralin para sa \'<i>$a->assignment</i>\'<br /><br />
Makikita mo itong nakakabit sa <a href=\"$a->url\">ipinasa mong takdang-aralin</a>.';
$string['assignmentname'] = 'Pangalan ng takdang-aralin';
$string['assignmenttype'] = 'Uri ng takdang-aralin';
$string['availabledate'] = 'Magagamit mula ';
$string['comment'] = 'Opinyon';
$string['commentinline'] = 'Opinyong inline';
$string['configmaxbytes'] = 'Default na maksimum na laki ng takdang-aralin para sa lahat ng takdang-aralin na nasa site (alinsunod sa limitasyon sa kurso at iba pang lokal na kaayusan)';
$string['description'] = 'Deskripsiyon';
$string['duedate'] = 'Huling araw ng pasahan';
$string['duedateno'] = 'Walang huling araw ng pasahan';
$string['early'] = '$a na maaga';
$string['editmysubmission'] = 'Iedit ang ipinasa ko';
$string['emailteachermail'] = 'Binago ni $a->username ang ipinasa niyang takdang -aralin para sa \'$a->assignment\'

Makukuha ito rito:

$a->url';
$string['emailteachermailhtml'] = 'Binago ni $a->username ang kanyang ipinasang takdang-aralin para sa <i>\'$a->assignment\'</i><br /><br />
Makukuha ito sa <a href=\"$a->url\">web site</a>.';
$string['emailteachers'] = 'Hudyat na email para sa mga guro';
$string['emptysubmission'] = 'Wala ka pang ipinapasang anuman';
$string['existingfiledeleted'] = 'Ang kasalukuyang file ay binura na: $a';
$string['failedupdatefeedback'] = 'Nabigong baguhin ang puna sa ipinasa ni user $a';
$string['feedback'] = 'Puna';
$string['feedbackfromteacher'] = 'Puna mula sa $a';
$string['feedbackupdated'] = 'Nabago na ang puna sa mga ipinasa ng $a tao';
$string['guestnoupload'] = 'Paumanhin nguni\'t hindi pinapahintulutang mag-aplowd ang bisita.';
$string['helpoffline'] = '<p>Kapakipakinabang ito kapag ang takdang-aralin ay ginagawa sa labas ng Moodle.  Maaari itong isang bagay sa iba pang lugar sa web o harapan.</p><p>Maaaring makakita ng deskripsyon ng takdang-aralin ang mga mag-aaral, nguni hindi puwedeng mag-aplowd ng file o anupaman.  Gumagana ng normal ang pagmamarka, at tatanggap ng patalastas hinggil sa marka nila ang mga mag-aaral</p>';
$string['helponline'] = '<p>Ang uri ng takdang-aralin na ito ay humihiling sa mga user na mag-edit ng teksto, gamit ang mga normal na editing tool.  Maaari itong markahan ng mga guro nang online, at puwede ring magdagdag ng inline na puna o pagbabago.</p><p>(Kung pamilyar ka sa mga lumang bersiyon ng Moodle, pareho ang silbi ng uri ng Takdang-aralin na ito sa lumang diyornal na modyul.)</p>';
$string['helpuploadsingle'] = '<p>Ang uri ng takdang-aralin na ito ay pinapahintulutan ang bawat kalahok na mag-aplowd ng isang file, anuman ang uri.</p><p>Maaari itong maging Word processor na dokumento, o isang larawan, isang nakazip na web site, o anumang bagay na hilingin mong ipasa nila.</p>';
$string['late'] = '$a na huli';
$string['maximumgrade'] = 'Pinakamataas na marka';
$string['maximumsize'] = 'Pinakamataas na laki';
$string['modulename'] = 'Takdang-aralin';
$string['modulenameplural'] = 'Mga takdang-aralin';
$string['newsubmissions'] = 'Ipinasang takdang-aralin';
$string['noassignments'] = 'Wala pang takdang-aralin';
$string['noattempts'] = 'Wala pang kumukuha ng takdang-aralin na ito';
$string['notgradedyet'] = 'Hindi pa namamarkahan';
$string['notsubmittedyet'] = 'Hindi pa naipapasa';
$string['overwritewarning'] = 'Babala: kung mag-aaplowd kang mul, MAPAPALITAN nito ang kasalukuyan mong ipinasa';
$string['preventlate'] = 'Pigilan ang pagpapasa nang hul';
$string['saveallfeedback'] = 'Isave ang lahat ng aking puna';
$string['submission'] = 'Ipinasa';
$string['submissionfeedback'] = 'Puna sa ipinasa';
$string['submissions'] = 'Mga ipinasa';
$string['submissionsaved'] = 'Naisave na ang mga pagbabago mo';
$string['submitassignment'] = 'Ipasa ang iyong takdang-aralin sa pamamagitan ng form na ito';
$string['submitted'] = 'Naipasa na';
$string['typeoffline'] = 'Offline na aktibidad';
$string['typeonline'] = 'Online na teksto';
$string['typeuploadsingle'] = 'Mag-aplowd ng isang file lamang';
$string['uploadbadname'] = 'May mga kakaibang titik ang filename na ito at hindi puwedeng maiaplowd';
$string['uploadedfiles'] = 'mga naiaplowd nang file';
$string['uploaderror'] = 'May error na naganap habang isinisave ang file sa server';
$string['uploadfailnoupdate'] = 'OK ang pagkakaaplowd ng file pero hindi mabago ang ipinasa mo!';
$string['uploadfiletoobig'] = 'Paumanhin, pero masyadong malaki ang file na iyan (ang limitasyon ay $a bytes)';
$string['uploadnofilefound'] = 'Wala pong makitang file - sigurado ba kayong may pinili kayong file para iaplowd?';
$string['uploadnotregistered'] = 'OK ang pagkakaaplowd ng \'$a\' pero hindi rumehistro ang ipinasa!';
$string['uploadsuccess'] = 'Matagumpay na naiaplowd ang \'$a\' ';
$string['viewfeedback'] = 'Tingnan ang mga marka at puna ng takdang-aralin';
$string['viewsubmissions'] = 'Tingnan ang $a naipasa nang takdang-aralin';
$string['yoursubmission'] = 'Ang iyong ipinasa';

?>
